==> nextcloud-19.0.1-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/files/l10n/en_GB.js <==
OC.L10N.register(
    "files",
    {
    "Storage is temporarily not available" : "Storage is temporarily not available",
    "Storage invalid" : "Storage invalid",
    "Unknown error" : "Unknown error",
    "File could not be found" : "File could not be found",
    "Move or copy" : "Move or copy",
    "Download" : "Download",
    "Delete" : "Delete",
    "Home" : "Home",
    "Close" : "Close",
    "Favorites" : "Favourites",
    "Could not create folder \"{dir}\"" : "Could not create folder \"{dir}\"",
    "Upload cancelled." : "Upload cancelled.",
    "…" : "…",
    "Unable to upload {filename} as it is a directory or has 0 bytes" : "Unable to upload {filename} as it is a directory or has 0 bytes",
    "Not enough free space, you are uploading {size1} but only {size2} is left" : "Not enough free space, you are uploading {size1} but only {size2} is left",
    "Target folder \"{dir}\" does not exist any more" : "Target folder \"{dir}\" does not exist any more",
    "Not enough free space" : "Not enough free space",
    "Uploading …" : "Uploading …",
    "{loadedSize} of {totalSize} ({bitrate})" : "{loadedSize} of {totalSize} ({bitrate})",
    "Target folder does not exist any more" : "Target folder does not exist any more",
    "Error when assembling chunks, status code {status}" : "Error when assembling chunks, status code {status}",
    "Actions" : "Actions",
    "Rename" : "Rename",
    "Copy" : "Copy",
    "Delete file" : "Delete file",
    "Delete folder" : "Delete folder",
    "Disconnect storage" : "Disconnect storage",
    "Unshare" : "Unshare",
    "Could not load info for file \"{file}\"" : "Could not load info for file \"{file}\"",
    "Files" : "Files",
    "Details" : "Details",
    "Select" : "Select",
    "Pending" : "Pending",
    "Unable to determine date" : "Unable to determine date",
    "This operation is forbidden" : "This operation is forbidden",
    "This directory is unavailable, please check the logs or contact the administrator" : "This directory is unavailable, please check the logs or contact the administrator",
    "Could not move \"{file}\", target exists" : "Could not move \"{file}\", target exists",
    "Could not move \"{file}\"" : "Could not move \"{file}\"",
    "Could not copy \"{file}\", target exists" : "Could not copy \"{file}\", target exists",
    "Could not copy \"{file}\"" : "Could not copy \"{file}\"",
    "Copied {origin} inside {destination}" : "Copied {origin} inside {destination}",
    "Copied {origin} and {nbfiles} other files inside {destination}" : "Copied {origin} and {nbfiles} other files inside {destination}",
    "{newName} already exists" : "{newName} already exists",
    "Could not rename \"{fileName}\", it does not exist any more" : "Could not rename \"{fileName}\", it does not exist any more",
    "The name \"{targetName}\" is already used in the folder \"{dir}\". Please choose a different name." : "The name \"{targetName}\" is already used in the folder \"{dir}\". Please choose a different name.",
    "Could not rename \"{fileName}\"" : "Could not rename \"{fileName}\"",
    "Could not create file \"{file}\"" : "Could not create file \"{file}\"",
    "Could not create file \"{file}\" because it already exists" : "Could not create file \"{file}\" because it already exists",
    "Could not create folder \"{dir}\" because it already exists" : "Could not create folder \"{dir}\" because it already exists",
    "Error deleting file \"{fileName}\"." : "Error deleting file \"{fileName}\".",
    "No search results in other folders for {tag}{filter}{endtag}" : "No search results in other folders for {tag}{filter}{endtag}",
    "Name" : "Name",
    "Size" : "Size",
    "Modified" : "Modified",
    "_%n folder_::_%n folders_" : ["%n folder","%n folders"],
    "_%n file_::_%n files_" : ["%n file","%n files"],
    "{dirs} and {files}" : "{dirs} and {files}",
    "_including %n hidden_::_including %n hidden_" : ["including %n hidden","including %n hidden"],
    "You don’t have permission to upload or create files here" : "You don’t have permission to upload or create files here",
    "_Uploading %n file_::_Uploading %n files_" : ["Uploading %n file","Uploading %n files"],
    "New" : "New",
    "{used} of {quota} used" : "{used} of {quota} used",
    "{used} used" : "{used} used",
    "\"{name}\" is an invalid file name." : "\"{name}\" is an invalid file name.",
    "File name cannot be empty." : "File name cannot be empty.",
    "\"/\" is not allowed inside a file name." : "\"/\" is not allowed inside a file name.",
    "\"{name}\" is not an allowed filetype" : "\"{name}\" is not an allowed filetype",
    "Storage of {owner} is full, files can not be updated or synced anymore!" : "Storage of {owner} is full, files can not be updated or synced anymore!",
    "Your storage is full, files can not be updated or synced anymore!" : "Your storage is full, files can not be updated or synced anymore!",
    "Storage of {owner} is almost full ({usedSpacePercent}%)" : "Storage of {owner} is almost full ({usedSpacePercent}%)",
    "Your storage is almost full ({usedSpacePercent}%)" : "Your storage is almost full ({usedSpacePercent}%)",
    "_matches '{filter}'_::_match '{filter}'_" : ["matches '{filter}'","match '{filter}'"],
    "View in folder" : "View in folder",
    "Copied!" : "Copied!",
    "Copy direct link (only works for users who have access to this file/folder)" : "Copy direct link (only works for users who have access to this file/folder)",
    "Path" : "Path",
    "_%n byte_::_%n bytes_" : ["%n byte","%n bytes"],
    "Favorited" : "Favourited",
    "Favorite" : "Favourite",
    "New folder" : "New folder",
    "Upload file" : "Upload file",
    "Recent" : "Recent",
    "Not favorited" : "Not favourited",
    "Remove from favorites" : "Remove from favourites",
    "Add to favorites" : "Add to favourites",
    "An error occurred while trying to update the tags" : "An error occurred whilst trying to update the tags",
    "Added to favorites" : "Added to favourites",
    "Removed from favorites" : "Removed from favourites",
    "You added {file} to your favorites" : "You added {file} to your favourites",
    "You removed {file} from your favorites" : "You removed {file} from your favourites",
    "File changes" : "File changes",
    "Created by {user}" : "Created by {user}",
    "Changed by {user}" : "Changed by {user}",
    "Deleted by {user}" : "Deleted by {user}",
    "Restored by {user}" : "Restored by {user}",
    "Renamed by {user}" : "Renamed by {user}",
    "Moved by {user}" : "Moved by {user}",
    "\"remote user\"" : "\"remote user\"",
    "You created {file}" : "You created {file}",
    "You created an encrypted file in {file}" : "You created an encrypted file in {file}",
    "{user} created {file}" : "{user} created {file}",
    "{user} created an encrypted file in {file}" : "{user} created an encrypted file in {file}",
    "{file} was created in a public folder" : "{file} was created in a public folder",
    "You changed {file}" : "You changed {file}",
    "You changed an encrypted file in {file}" : "You changed an encrypted file in {file}",
    "{user} changed {file}" : "{user} changed {file}",
    "{user} changed an encrypted file in {file}" : "{user} changed an encrypted file in {file}",
    "You deleted {file}" : "You deleted {file}",
    "You deleted an encrypted file in {file}" : "You deleted an encrypted file in {file}",
    "{user} deleted {file}" : "{user} deleted {file}",
    "{user} deleted an encrypted file in {file}" : "{user} deleted an encrypted file in {file}",
    "You restored {file}" : "You restored {file}",
    "{user} restored {file}" : "{user} restored {file}",
    "You renamed {oldfile} to {newfile}" : "You renamed {oldfile} to {newfile}",
    "{user} renamed {oldfile} to {newfile}" : "{user} renamed {oldfile} to {newfile}",
    "You moved {oldfile} to {newfile}" : "You moved {oldfile} to {newfile}",
    "{user} moved {oldfile} to {newfile}" : "{user} moved {oldfile} to {newfile}",
    "A file has been added to or removed from your <strong>favorites</strong>" : "A file has been added to or removed from your <strong>favourites</strong>",
    "A file or folder has been <strong>changed</strong> or <strong>renamed</strong>" : "A file or folder has been <strong>changed</strong> or <strong>renamed</strong>",
    "A new file or folder has been <strong>created</strong>" : "A new file or folder has been <strong>created</strong>",
    "A file or folder has been <strong>deleted</strong>" : "A file or folder has been <strong>deleted</strong>",
    "Limit notifications about creation and changes to your <strong>favorite files</strong> <em>(Stream only)</em>" : "Limit notifications about creation and changes to your <strong>favourite files</strong> <em>(Stream only)</em>",
    "A file or folder has been <strong>restored</strong>" : "A file or folder has been <strong>restored</strong>",
    "All files" : "All files",
    "Unlimited" : "Unlimited",
    "Upload (max. %s)" : "Upload (max. %s)",
    "Accept" : "Accept",
    "File Management" : "File Management",
    "Change" : "Change",
    "Tags" : "Tags",
    "%s used" : "%s used",
    "%1$s of %2$s used" : "%1$s of %2$s used",
    "Settings" : "Settings",
    "Show hidden files" : "Show hidden files",
    "WebDAV" : "WebDAV",
    "No files in here" : "No files in here",
    "Upload some content or sync with your devices!" : "Upload some content or sync with your devices!",
    "No entries found in this folder" : "No entries found in this folder",
    "Select all" : "Select all",
    "Upload too large" : "Upload too large",
    "The files you are trying to upload exceed the maximum size for file uploads on this server." : "The files you are trying to upload exceed the maximum size for file uploads on this server.",
    "No favorites yet" : "No favourites yet",
    "Files and folders you mark as favorite will show up here" : "Files and folders you mark as favourite will show up here",
    "Deleted files" : "Deleted files",
    "Shares" : "Shares",
    "Shared with others" : "Shared with others",
    "Shared with you" : "Shared with you",
    "Shared by link" : "Shared by link",
    "Text file" : "Text file",
    "New text file.txt" : "New text file.txt",
    "Use this address to <a href=\"%s\" target=\"_blank\" rel=\"noreferrer noopener\">access your Files via WebDAV</a>" : "Use this address to <a href=\"%s\" target=\"_blank\" rel=\"noreferrer noopener\">access your Files via WebDAV</a>"
},
"nplurals=2; plural=(n != 1);");

==> nextcloud-21.0.1-2-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/files/l10n/en_GB.js <==
OC.L10N.register(
    "files",
    {
    "Storage is temporarily not available" : "Storage is temporarily not available",
    "Storage invalid" : "Storage invalid",
    "Unknown error" : "Unknown error",
    "File could not be found" : "File could not be found",
    "Move or copy" : "Move or copy",
    "Download" : "Download",
    "Delete" : "Delete",
    "Home" : "Home",
    "Close" : "Close",
    "Favorites" : "Favourites",
    "Could not create folder \"{dir}\"" : "Could not create folder \"{dir}\"",
    "Upload cancelled." : "Upload cancelled.",
    "…" : "…",
    "Unable to upload {filename} as it is a directory or has 0 bytes" : "Unable to upload {filename} as it is a directory or has 0 bytes",
    "Not enough free space, you are uploading {size1} but only {size2} is left" : "Not enough free space, you are uploading {size1} but only {size2} is left",
    "Target folder \"{dir}\" does not exist any more" : "Target folder \"{dir}\" does not exist any more",
    "Not enough free space" : "Not enough free space",
    "Uploading …" : "Uploading …",
    "{loadedSize} of {totalSize} ({bitrate})" : "{loadedSize} of {totalSize} ({bitrate})",
    "Target folder does not exist any more" : "Target folder does not exist any more",
    "Error when assembling chunks, status code {status}" : "Error when assembling chunks, status code {status}",
    "Actions" : "Actions",
    "Rename" : "Rename",
    "Copy" : "Copy",
    "Delete file" : "Delete file",
    "Delete folder" : "Delete folder",
    "Disconnect storage" : "Disconnect storage",
    "Could not load info for file \"{file}\"" : "Could not load info for file \"{file}\"",
    "Files" : "Files",
    "Details" : "Details",
    "Select" : "Select",
    "Pending" : "Pending",
    "Unable to determine date" : "Unable to determine date",
    "This operation is forbidden" : "This operation is forbidden",
    "This directory is unavailable, please check the logs or contact the administrator" : "This directory is unavailable, please check the logs or contact the administrator",
    "Could not move \"{file}\", target exists" : "Could not move \"{file}\", target exists",
    "Could not move \"{file}\"" : "Could not move \"{file}\"",
    "Could not copy \"{file}\", target exists" : "Could not copy \"{file}\", target exists",
    "Could not copy \"{file}\"" : "Could not copy \"{file}\"",
    "Copied {origin} inside {destination}" : "Copied {origin} inside {destination}",
    "Copied {origin} and {nbfiles} other files inside {destination}" : "Copied {origin} and {nbfiles} other files inside {destination}",
    "{newName} already exists" : "{newName} already exists",
    "Could not rename \"{fileName}\", it does not exist any more" : "Could not rename \"{fileName}\", it does not exist any more",
    "The name \"{targetName}\" is already used in the folder \"{dir}\". Please choose a different name." : "The name \"{targetName}\" is already used in the folder \"{dir}\". Please choose a different name.",
    "Could not rename \"{fileName}\"" : "Could not rename \"{fileName}\"",
    "Could not create file \"{file}\"" : "Could not create file \"{file}\"",
    "Could not create file \"{file}\" because it already exists" : "Could not create file \"{file}\" because it already exists",
    "Could not create folder \"{dir}\" because it already exists" : "Could not create folder \"{dir}\" because it already exists",
    "Error deleting file \"{fileName}\"." : "Error deleting file \"{fileName}\".",
    "No search results in other folders for {tag}{filter}{endtag}" : "No search results in other folders for {tag}{filter}{endtag}",
    "Name" : "Name",
    "Size" : "Size",
    "Modified" : "Modified",
    "_%n folder_::_%n folders_" : ["%n folder","%n folders"],
    "_%n file_::_%n files_" : ["%n file","%n files"],
    "{dirs} and {files}" : "{dirs} and {files}",
    "_including %n hidden_::_including %n hidden_" : ["including %n hidden","including %n hidden"],
    "You don’t have permission to upload or create files here" : "You don’t have permission to upload or create files here",
    "_Uploading %n file_::_Uploading %n files_" : ["Uploading %n file","Uploading %n files"],
    "New" : "New",
    "{used} of {quota} used" : "{used} of {quota} used",
    "{used} used" : "{used} used",
    "\"{name}\" is an invalid file name." : "\"{name}\" is an invalid file name.",
    "File name cannot be empty." : "File name cannot be empty.",
    "\"/\" is not allowed inside a file name." : "\"/\" is not allowed inside a file name.",
    "\"{name}\" is not an allowed filetype" : "\"{name}\" is not an allowed filetype",
    "Storage of {owner} is full, files can not be updated or synced anymore!" : "Storage of {owner} is full, files can not be updated or synced anymore!",
    "Your storage is full, files can not be updated or synced anymore!" : "Your storage is full, files can not be updated or synced anymore!",
    "_matches '{filter}'_::_match '{filter}'_" : ["matches '{filter}'","match '{filter}'"],
    "View in folder" : "View in folder",
    "Copied!" : "Copied!",
    "Copy direct link (only works for users who have access to this file/folder)" : "Copy direct link (only works for users who have access to this file/folder)",
    "Path" : "Path",
    "_%n byte_::_%n bytes_" : ["%n byte","%n bytes"],
    "Favorited" : "Favourited",
    "Favorite" : "Favourite",
    "New folder" : "New folder",
    "Upload file" : "Upload file",
    "Recent" : "Recent",
    "Not favorited" : "Not favourited",
    "Remove from favorites" : "Remove from favourites",
    "Add to favorites" : "Add to favourites",
    "An error occurred while trying to update the tags" : "An error occurred whilst trying to update the tags",
    "Added to favorites" : "Added to favourites",
    "Removed from favorites" : "Removed from favourites",
    "You added {file} to your favorites" : "You added {file} to your favourites",
    "You removed {file} from your favorites" : "You removed {file} from your favourites",
    "File changes" : "File changes",
    "Created by {user}" : "Created by {user}",
    "Changed by {user}" : "Changed by {user}",
    "Deleted by {user}" : "Deleted by {user}",
    "Restored by {user}" : "Restored by {user}",
    "Renamed by {user}" : "Renamed by {user}",
    "Moved by {user}" : "Moved by {user}",
    "\"remote user\"" : "\"remote user\"",
    "You created {file}" : "You created {file}",
    "You created an encrypted file in {file}" : "You created an encrypted file in {file}",
    "{user} created {file}" : "{user} created {file}",
    "{user} created an encrypted file in {file}" : "{user} created an encrypted file in {file}",
    "{file} was created in a public folder" : "{file} was created in a public folder",
    "You changed {file}" : "You changed {file}",
    "You changed an encrypted file in {file}" : "You changed an encrypted file in {file}",
    "{user} changed {file}" : "{user} changed {file}",
    "{user} changed an encrypted file in {file}" : "{user} changed an encrypted file in {file}",
    "You deleted {file}" : "You deleted {file}",
    "You deleted an encrypted file in {file}" : "You deleted an encrypted file in {file}",
    "{user} deleted {file}" : "{user} deleted {file}",
    "{user} deleted an encrypted file in {file}" : "{user} deleted an encrypted file in {file}",
    "You restored {file}" : "You restored {file}",
    "{user} restored {file}" : "{user} restored {file}",
    "You renamed {oldfile} to {newfile}" : "You renamed {oldfile} to {newfile}",
    "{user} renamed {oldfile} to {newfile}" : "{user} renamed {oldfile} to {newfile}",
    "You moved {oldfile} to {newfile}" : "You moved {oldfile} to {newfile}",
    "{user} moved {oldfile} to {newfile}" : "{user} moved {oldfile} to {newfile}",
    "A file has been added to or removed from your <strong>favorites</strong>" : "A file has been added to or removed from your <strong>favourites</strong>",
    "A file or folder has been <strong>changed</strong>" : "A file or folder has been <strong>changed</strong>",
    "All files" : "All files",
    "Unlimited" : "Unlimited",
    "Upload (max. %s)" : "Upload (max. %s)",
    "Accept" : "Accept",
    "in %s" : "in %s",
    "File Management" : "File Management",
    "Change" : "Change",
    "Tags" : "Tags",
    "%s used" : "%s used",
    "%1$s of %2$s used" : "%1$s of %2$s used",
    "Settings" : "Settings",
    "Show hidden files" : "Show hidden files",
    "WebDAV" : "WebDAV",
    "No files in here" : "No files in here",
    "Upload some content or sync with your devices!" : "Upload some content or sync with your devices!",
    "No entries found in this folder" : "No entries found in this folder",
    "Select all" : "Select all",
    "Upload too large" : "Upload too large",
    "The files you are trying to upload exceed the maximum size for file uploads on this server." : "The files you are trying to upload exceed the maximum size for file uploads on this server.",
    "No favorites yet" : "No favourites yet",
    "Files and folders you mark as favorite will show up here" : "Files and folders you mark as favourite will show up here",
    "Deleted files" : "Deleted files",
    "Shares" : "Shares",
    "Shared with others" : "Shared with others",
    "Shared with you" : "Shared with you",
    "Shared by link" : "Shared by link",
    "Text file" : "Text file",
    "New text file.txt" : "New text file.txt",
    "Unshare" : "Unshare",
    "Storage of {owner} is almost full ({usedSpacePercent}%)" : "Storage of {owner} is almost full ({usedSpacePercent}%)",
    "Your storage is almost full ({usedSpacePercent}%)" : "Your storage is almost full ({usedSpacePercent}%)",
    "A file or folder has been <strong>changed</strong> or <strong>renamed</strong>" : "A file or folder has been <strong>changed</strong> or <strong>renamed</strong>",
    "A new file or folder has been <strong>created</strong>" : "A new file or folder has been <strong>created</strong>",
    "A file or folder has been <strong>deleted</strong>" : "A file or folder has been <strong>deleted</strong>",
    "Limit notifications about creation and changes to your <strong>favorite files</strong> <em>(Stream only)</em>" : "Limit notifications about creation and changes to your <strong>favourite files</strong> <em>(Stream only)</em>",
    "A file or folder has been <strong>restored</strong>" : "A file or folder has been <strong>restored</strong>"
},
"nplurals=2; plural=(n != 1);");
